ServiceInfo

Struct ServiceInfo 

pub struct ServiceInfo { /* private fields */ }
A Closed Caption Service Information block as stored in CDP (SMPTE 334-2).

Implementations

Source

impl ServiceInfo

pub fn parse(data: &[u8]) -> Result<Self, ParserError>

Parse a sequence of bytes into a valid Service Descriptor.

pub fn is_start(&self) -> bool

This packet begins a complete set of Service Information.

pub fn set_start(&mut self, start: bool)

Set the start flag in this Service Information.

pub fn is_change(&self) -> bool

This packet is an update to a previously sent Service Information. Can only be true when is_start is also true.

pub fn set_change(&mut self, change: bool)

Set the change flag in this Service Information. If true, then the start flag will also be set to true.

pub fn is_complete(&self) -> bool

This packet concludes a complete set of Service Information.

pub fn set_complete(&mut self, complete: bool)

Set the complete flag in this Service Information.

pub fn services(&self) -> &[ServiceEntry]

The list of services described by this Service Information.

pub fn clear_services(&mut self)

Remove all services from this Service Information block.

pub fn add_service(&mut self, service: ServiceEntry) -> Result<(), WriterError>

Add a service to this Service Information block.

pub fn byte_len(&self) -> usize

The length in bytes of this Service Information.

pub fn write<W: Write>(&mut self, w: &mut W) -> Result<(), Error>

Write this Service Information to a sequence of bytes.

pub fn write_into_unchecked(&self, data: &mut [u8]) -> usize

Write this Service Information into a preallocated sequence of bytes. data must be at least byte_len bytes.